@@ -11,8 +11,7 @@ from .compound import (Compound,
                        Location,
                        Relation,
                        Shaped)
-from .geometry import (Coordinate,
-                       Geometry)
+from .geometry import Geometry
 from .iterable import non_negative_min
 from .multipoint import Multipoint
 from .packing import (MIN_MIX_NON_EMPTY_COMPONENTS,
@@ -20,13 +19,13 @@ from .packing import (MIN_MIX_NON_EMPTY_COMPONENTS,
 from .point import Point
 
 
-class Mix(Indexable[Coordinate]):
+class Mix(Indexable[Scalar]):
     __slots__ = '_components', '_discrete', '_linear', '_shaped'
 
     def __init__(self,
-                 discrete: Maybe[Multipoint[Coordinate]],
-                 linear: Maybe[Linear[Coordinate]],
-                 shaped: Maybe[Shaped[Coordinate]]) -> None:
+                 discrete: Maybe[Multipoint[Scalar]],
+                 linear: Maybe[Linear[Scalar]],
+                 shaped: Maybe[Shaped[Scalar]]) -> None:
         """
         Initializes mix.
 
@@ -36,11 +35,12 @@ class Mix(Indexable[Coordinate]):
             ``O(1)``
         """
         self._components = self._discrete, self._linear, self._shaped = (
-            discrete, linear, shaped)
+            discrete, linear, shaped
+        )
 
     __repr__ = generate_repr(__init__)
 
-    def __and__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __and__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns intersection of the mix with the other geometry.
 
@@ -118,7 +118,7 @@ class Mix(Indexable[Coordinate]):
 
     __rand__ = __and__
 
-    def __contains__(self, point: Point[Coordinate]) -> bool:
+    def __contains__(self, point: Point[Scalar]) -> bool:
         """
         Checks if the mix contains the point.
 
@@ -179,7 +179,7 @@ class Mix(Indexable[Coordinate]):
         """
         return bool(self.locate(point))
 
-    def __eq__(self, other: 'Mix[Coordinate]') -> bool:
+    def __eq__(self, other: 'Mix[Scalar]') -> bool:
         """
         Checks if mixes are equal.
 
@@ -227,7 +227,7 @@ class Mix(Indexable[Coordinate]):
                                  if isinstance(other, Mix)
                                  else NotImplemented)
 
-    def __ge__(self, other: Compound[Coordinate]) -> bool:
+    def __ge__(self, other: Compound[Scalar]) -> bool:
         """
         Checks if the mix is a superset of the other geometry.
 
@@ -284,7 +284,7 @@ class Mix(Indexable[Coordinate]):
                     if isinstance(other, Compound)
                     else NotImplemented))
 
-    def __gt__(self, other: Compound[Coordinate]) -> bool:
+    def __gt__(self, other: Compound[Scalar]) -> bool:
         """
         Checks if the mix is a strict superset of the other geometry.
 
@@ -386,7 +386,7 @@ class Mix(Indexable[Coordinate]):
         """
         return hash(self._components)
 
-    def __le__(self, other: Compound[Coordinate]) -> bool:
+    def __le__(self, other: Compound[Scalar]) -> bool:
         """
         Checks if the mix is a subset of the other geometry.
 
@@ -443,7 +443,7 @@ class Mix(Indexable[Coordinate]):
                     if isinstance(other, Compound)
                     else NotImplemented))
 
-    def __lt__(self, other: Compound[Coordinate]) -> bool:
+    def __lt__(self, other: Compound[Scalar]) -> bool:
         """
         Checks if the mix is a strict subset of the other geometry.
 
@@ -499,7 +499,7 @@ class Mix(Indexable[Coordinate]):
                      if isinstance(other, Compound)
                      else NotImplemented))
 
-    def __or__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __or__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns union of the mix with the other geometry.
 
@@ -575,7 +575,7 @@ class Mix(Indexable[Coordinate]):
 
     __ror__ = __or__
 
-    def __rsub__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __rsub__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns difference of the other geometry with the mix.
 
@@ -611,7 +611,7 @@ class Mix(Indexable[Coordinate]):
         return ((other - self.discrete) & (other - self.linear)
                 & other - self.shaped)
 
-    def __sub__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __sub__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns difference of the mix with the other geometry.
 
@@ -659,7 +659,7 @@ class Mix(Indexable[Coordinate]):
                         self.shaped - other, self._context.empty,
                         self._context.mix_cls)
 
-    def __xor__(self, other: Compound[Coordinate]) -> Compound[Coordinate]:
+    def __xor__(self, other: Compound[Scalar]) -> Compound[Scalar]:
         """
         Returns symmetric difference of the mix with the other geometry.
 
@@ -736,7 +736,7 @@ class Mix(Indexable[Coordinate]):
     __rxor__ = __xor__
 
     @property
-    def centroid(self) -> Point[Coordinate]:
+    def centroid(self) -> Point[Scalar]:
         """
         Returns centroid of the mix.
 
@@ -785,7 +785,7 @@ class Mix(Indexable[Coordinate]):
                 else self.shaped).centroid
 
     @property
-    def discrete(self) -> Maybe[Multipoint[Coordinate]]:
+    def discrete(self) -> Maybe[Multipoint[Scalar]]:
         """
         Returns disrete component of the mix.
 
@@ -808,7 +808,7 @@ class Mix(Indexable[Coordinate]):
         return self._discrete
 
     @property
-    def shaped(self) -> Maybe[Shaped[Coordinate]]:
+    def shaped(self) -> Maybe[Shaped[Scalar]]:
         """
         Returns shaped component of the mix.
 
@@ -835,7 +835,7 @@ class Mix(Indexable[Coordinate]):
         return self._shaped
 
     @property
-    def linear(self) -> Maybe[Linear[Coordinate]]:
+    def linear(self) -> Maybe[Linear[Scalar]]:
         """
         Returns linear component of the mix.
 
@@ -857,7 +857,7 @@ class Mix(Indexable[Coordinate]):
         """
         return self._linear
 
-    def distance_to(self, other: Geometry[Coordinate]) -> Scalar:
+    def distance_to(self, other: Geometry[Scalar]) -> Scalar:
         """
         Returns distance between the mix and the other geometry.
 
@@ -956,7 +956,7 @@ class Mix(Indexable[Coordinate]):
         if isinstance(self.shaped, Indexable):
             self.shaped.index()
 
-    def locate(self, point: Point[Coordinate]) -> Location:
+    def locate(self, point: Point[Scalar]) -> Location:
         """
         Finds location of the point relative to the mix.
 
@@ -1021,7 +1021,7 @@ class Mix(Indexable[Coordinate]):
                 return location
         return Location.EXTERIOR
 
-    def relate(self, other: Compound[Coordinate]) -> Relation:
+    def relate(self, other: Compound[Scalar]) -> Relation:
         """
         Finds relation between the mix and the other geometry.
 
@@ -1077,7 +1077,7 @@ class Mix(Indexable[Coordinate]):
 
     def rotate(self,
                angle: Angle,
-               point: Optional[Point[Coordinate]] = None) -> 'Mix[Coordinate]':
+               point: Optional[Point[Scalar]] = None) -> 'Mix[Scalar]':
         """
         Rotates the mix by given angle around given point.
 
@@ -1134,8 +1134,8 @@ class Mix(Indexable[Coordinate]):
                                      self.shaped.rotate(angle, point))
 
     def scale(self,
-              factor_x: Coordinate,
-              factor_y: Optional[Coordinate] = None) -> Compound[Coordinate]:
+              factor_x: Scalar,
+              factor_y: Optional[Scalar] = None) -> Compound[Scalar]:
         """
         Scales the mix by given factor.
 
@@ -1199,11 +1199,10 @@ class Mix(Indexable[Coordinate]):
                       if factor_x or factor_y
                       else
                       self._context.multipoint_cls(
-                              [self._context.point_cls(factor_x, factor_y)])))
+                              [self._context.point_cls(factor_x, factor_y)]
+                      )))
 
-    def translate(self,
-                  step_x: Coordinate,
-                  step_y: Coordinate) -> 'Mix[Coordinate]':
+    def translate(self, step_x: Scalar, step_y: Scalar) -> 'Mix[Scalar]':
         """
         Translates the mix by given step.
 
@@ -1329,11 +1328,12 @@ class Mix(Indexable[Coordinate]):
                               self.shaped.polygons
                               if isinstance(self.shaped,
                                             self._context.multipolygon_cls)
-                              else [self.shaped]))):
+                              else [self.shaped]
+                      ))):
             raise ValueError('Linear component should not overlap '
                              'shaped component borders.')
 
-    def _relate_linear(self, other: Linear[Coordinate]) -> Relation:
+    def _relate_linear(self, other: Linear[Scalar]) -> Relation:
         if self.shaped is self._context.empty:
             linear_relation = self.linear.relate(other)
             if linear_relation is Relation.DISJOINT:
@@ -1378,7 +1378,7 @@ class Mix(Indexable[Coordinate]):
             else:
                 return shaped_relation
 
-    def _relate_mix(self, other: 'Mix[Coordinate]') -> Relation:
+    def _relate_mix(self, other: 'Mix[Scalar]') -> Relation:
         if self.shaped is other.shaped is self._context.empty:
             linear_components_relation = self.linear.relate(other.linear)
             if linear_components_relation is Relation.DISJOINT:
@@ -1527,7 +1527,8 @@ class Mix(Indexable[Coordinate]):
                                 else Relation.TOUCH)
                     else:
                         other_discrete_relation = self._relate_discrete(
-                                other.discrete)
+                                other.discrete
+                        )
                         if other_discrete_relation is Relation.CROSS:
                             return other_discrete_relation
                         elif (other_discrete_relation is Relation.ENCLOSED
@@ -1549,7 +1550,8 @@ class Mix(Indexable[Coordinate]):
                     return Relation.CROSS
                 else:
                     other_discrete_relation = self._relate_discrete(
-                            other.discrete)
+                            other.discrete
+                    )
                     if other_discrete_relation is Relation.CROSS:
                         return other_discrete_relation
                     elif (other_discrete_relation is Relation.ENCLOSED
@@ -1563,7 +1565,8 @@ class Mix(Indexable[Coordinate]):
                                 else Relation.TOUCH)
                     else:
                         discrete_relation = other._relate_discrete(
-                                self.discrete)
+                                self.discrete
+                        )
                         if discrete_relation is Relation.CROSS:
                             return discrete_relation
                         elif (discrete_relation is Relation.ENCLOSED
@@ -1592,7 +1595,8 @@ class Mix(Indexable[Coordinate]):
                         return Relation.CROSS
                     elif self.discrete is self._context.empty:
                         other_discrete_relation = self._relate_discrete(
-                                other.discrete)
+                                other.discrete
+                        )
                         return (other_discrete_relation
                                 if other_discrete_relation is Relation.CROSS
                                 else
@@ -1609,7 +1613,8 @@ class Mix(Indexable[Coordinate]):
                                        else Relation.TOUCH)))
                     elif other.discrete is self._context.empty:
                         discrete_relation = other._relate_discrete(
-                                self.discrete)
+                                self.discrete
+                        )
                         return (discrete_relation
                                 if discrete_relation is Relation.CROSS
                                 else
@@ -1624,7 +1629,8 @@ class Mix(Indexable[Coordinate]):
                                        else Relation.TOUCH)))
                     else:
                         other_discrete_relation = self._relate_discrete(
-                                other.discrete)
+                                other.discrete
+                        )
                         if other_discrete_relation is Relation.CROSS:
                             return other_discrete_relation
                         elif (other_discrete_relation is Relation.ENCLOSED
@@ -1632,7 +1638,8 @@ class Mix(Indexable[Coordinate]):
                             return Relation.CROSS
                         else:
                             discrete_relation = other._relate_discrete(
-                                    self.discrete)
+                                    self.discrete
+                            )
                             return (discrete_relation
                                     if discrete_relation is Relation.CROSS
                                     else (Relation.CROSS
@@ -1668,7 +1675,8 @@ class Mix(Indexable[Coordinate]):
                         return shaped_components_relation
                     else:
                         discrete_relation = other._relate_discrete(
-                                self.discrete).complement
+                                self.discrete
+                        ).complement
                         return (shaped_components_relation
                                 if (discrete_relation
                                     is shaped_components_relation)
@@ -1685,7 +1693,8 @@ class Mix(Indexable[Coordinate]):
                         return Relation.ENCLOSES
                     else:
                         discrete_relation = other._relate_discrete(
-                                self.discrete).complement
+                                self.discrete
+                        ).complement
                         return (Relation.ENCLOSES
                                 if discrete_relation in (Relation.COVER,
                                                          Relation.ENCLOSES,
@@ -1697,7 +1706,8 @@ class Mix(Indexable[Coordinate]):
             linear_components_relation = self.linear.relate(other.linear)
             if self.linear is other.linear is self._context.empty:
                 discrete_components_relation = self.discrete.relate(
-                        other.discrete)
+                        other.discrete
+                )
                 return (
                     shaped_components_relation
                     if (self.discrete is other.discrete is self._context.empty
@@ -1706,35 +1716,43 @@ class Mix(Indexable[Coordinate]):
                     (discrete_components_relation
                      if (discrete_components_relation is Relation.COMPOSITE
                          or discrete_components_relation is Relation.COMPONENT)
-                     else Relation.OVERLAP))
+                     else Relation.OVERLAP)
+                )
             elif self.linear is self._context.empty:
                 discrete_components_relation = other._relate_discrete(
-                        self.discrete)
+                        self.discrete
+                )
                 return (
                     Relation.COMPOSITE
                     if (discrete_components_relation is Relation.EQUAL
                         or discrete_components_relation is Relation.COMPONENT)
-                    else Relation.OVERLAP)
+                    else Relation.OVERLAP
+                )
             elif other.linear is self._context.empty:
                 discrete_components_relation = self._relate_discrete(
-                        other.discrete)
+                        other.discrete
+                )
                 return (
                     Relation.COMPONENT
                     if (discrete_components_relation is Relation.EQUAL
                         or discrete_components_relation is Relation.COMPONENT)
-                    else Relation.OVERLAP)
+                    else Relation.OVERLAP
+                )
             elif linear_components_relation is Relation.COMPOSITE:
                 discrete_components_relation = other._relate_discrete(
-                        self.discrete)
+                        self.discrete
+                )
                 return (
                     linear_components_relation
                     if (self.discrete is self._context.empty
                         or discrete_components_relation is Relation.EQUAL
                         or discrete_components_relation is Relation.COMPONENT)
-                    else Relation.OVERLAP)
+                    else Relation.OVERLAP
+                )
             elif linear_components_relation is Relation.EQUAL:
                 discrete_components_relation = self.discrete.relate(
-                        other.discrete)
+                        other.discrete
+                )
                 return (
                     shaped_components_relation
                     if (self.discrete is other.discrete is self._context.empty
@@ -1750,16 +1768,19 @@ class Mix(Indexable[Coordinate]):
                        if
                        (discrete_components_relation is Relation.COMPONENT
                         or discrete_components_relation is Relation.COMPOSITE)
-                       else Relation.OVERLAP))))
+                       else Relation.OVERLAP)))
+                )
             elif linear_components_relation is Relation.COMPONENT:
                 discrete_components_relation = self._relate_discrete(
-                        other.discrete)
+                        other.discrete
+                )
                 return (
                     linear_components_relation
                     if (other.discrete is self._context.empty
                         or discrete_components_relation is Relation.EQUAL
                         or discrete_components_relation is Relation.COMPONENT)
-                    else Relation.OVERLAP)
+                    else Relation.OVERLAP
+                )
             else:
                 return Relation.OVERLAP
         elif shaped_components_relation in (Relation.COMPONENT,
@@ -1781,7 +1802,8 @@ class Mix(Indexable[Coordinate]):
                         return shaped_components_relation
                     else:
                         discrete_relation = self._relate_discrete(
-                                other.discrete)
+                                other.discrete
+                        )
                         return (shaped_components_relation
                                 if (discrete_relation
                                     is shaped_components_relation)
@@ -1798,7 +1820,8 @@ class Mix(Indexable[Coordinate]):
                         return Relation.ENCLOSED
                     else:
                         discrete_relation = self._relate_discrete(
-                                other.discrete)
+                                other.discrete
+                        )
                         return (Relation.ENCLOSED
                                 if discrete_relation in (Relation.COMPONENT,
                                                          Relation.ENCLOSED,
@@ -1809,7 +1832,7 @@ class Mix(Indexable[Coordinate]):
         else:
             return shaped_components_relation
 
-    def _relate_discrete(self, other: Multipoint[Coordinate]) -> Relation:
+    def _relate_discrete(self, other: Multipoint[Scalar]) -> Relation:
         if self.shaped is self._context.empty:
             linear_relation = self.linear.relate(other)
             if linear_relation is Relation.DISJOINT:
@@ -1887,7 +1910,7 @@ class Mix(Indexable[Coordinate]):
                 else:
                     return linear_relation
 
-    def _relate_shaped(self, other: Shaped[Coordinate]) -> Relation:
+    def _relate_shaped(self, other: Shaped[Scalar]) -> Relation:
         if self.shaped is self._context.empty:
             linear_relation = self.linear.relate(other)
             if (linear_relation is Relation.DISJOINT
