@@ -36,8 +36,7 @@ from .compound import (Compound,
                        Relation,
                        Shaped)
 from .contour import Contour
-from .geometry import (Coordinate,
-                       Geometry)
+from .geometry import Geometry
 from .iterable import (flatten,
                        non_negative_min)
 from .multipoint import Multipoint
@@ -50,13 +49,13 @@ from .utils import (to_point_nearest_segment,
 Triangulation = Triangulation
 
 
-class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
+class Polygon(Indexable[Scalar], Shaped[Scalar]):
     __slots__ = ('_border', '_holes', '_holes_set', '_locate',
                  '_point_nearest_edge', '_segment_nearest_edge')
 
     def __init__(self,
-                 border: Contour[Coordinate],
-                 holes: Optional[Sequence[Contour[Coordinate]]] = None
+                 border: Contour[Scalar],
+                 holes: Optional[Sequence[Contour[Scalar]]] = None
                  ) -> None:
         """
         Initializes polygon.
@@ -85,7 +84,8 @@ class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
         edges = self.edges
         self._point_nearest_edge, self._segment_nearest_edge = (
             partial(to_point_nearest_segment, context, edges),
-            partial(to_segment_nearest_segment, context, edges))
+            partial(to_segment_nearest_segment, context, edges)
+        )
 
     __repr__ = generate_repr(__init__)
 
@@ -114,22 +114,25 @@ class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
         >>> polygon & polygon == polygon
         True
         """
-        return (complete_intersect_segment_with_polygon(other, self,
-                                                        context=self._context)
-                if isinstance(other, Segment)
-                else
-                (complete_intersect_multisegment_with_polygon(
-                        other, self,
-                        context=self._context)
-                 if isinstance(other, Linear)
-                 else ((complete_intersect_polygons(self, other,
-                                                    context=self._context)
-                        if self.holes or other.holes
-                        else complete_intersect_regions(self.border,
-                                                        other.border,
-                                                        context=self._context))
-                       if isinstance(other, Polygon)
-                       else NotImplemented)))
+        if isinstance(other, Segment):
+            return complete_intersect_segment_with_polygon(
+                    other, self,
+                    context=self._context
+            )
+        elif isinstance(other, Linear):
+            return complete_intersect_multisegment_with_polygon(
+                    other, self,
+                    context=self._context
+            )
+        else:
+            return ((complete_intersect_polygons(self, other,
+                                                 context=self._context)
+                     if self.holes or other.holes
+                     else complete_intersect_regions(self.border,
+                                                     other.border,
+                                                     context=self._context))
+                    if isinstance(other, Polygon)
+                    else NotImplemented)
 
     __rand__ = __and__
 
@@ -487,26 +490,28 @@ class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
         >>> polygon ^ polygon is EMPTY
         True
         """
-        return (self._unite_with_multipoint(other)
-                if isinstance(other, Multipoint)
-                else
-                (symmetric_subtract_polygon_from_segment(other, self,
-                                                         context=self._context)
-                 if isinstance(other, Segment)
-                 else
-                 (symmetric_subtract_polygon_from_multisegment(
-                         other, self,
-                         context=self._context)
-                  if isinstance(other, Linear)
-                  else (symmetric_subtract_polygons(self, other,
-                                                    context=self._context)
-                        if isinstance(other, Polygon)
-                        else NotImplemented))))
+        if isinstance(other, Multipoint):
+            return self._unite_with_multipoint(other)
+        elif isinstance(other, Segment):
+            return symmetric_subtract_polygon_from_segment(
+                    other, self,
+                    context=self._context
+            )
+        elif isinstance(other, Linear):
+            return symmetric_subtract_polygon_from_multisegment(
+                    other, self,
+                    context=self._context
+            )
+        else:
+            return (symmetric_subtract_polygons(self, other,
+                                                context=self._context)
+                    if isinstance(other, Polygon)
+                    else NotImplemented)
 
     __rxor__ = __xor__
 
     @property
-    def area(self) -> Coordinate:
+    def area(self) -> Scalar:
         """
         Returns area of the polygon.
 
@@ -608,14 +613,14 @@ class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
         >>> polygon.convex_hull == Polygon(polygon.border, [])
         True
         """
-        context = self._context
-        return (self
-                if self.is_convex
-                else
-                context.polygon_cls(
-                        context.contour_cls(context.points_convex_hull(
-                                self.border.vertices)),
-                        []))
+        if self.is_convex:
+            return self
+        else:
+            context = self._context
+            border = context.contour_cls(context.points_convex_hull(
+                    self.border.vertices
+            ))
+            return context.polygon_cls(border, [])
 
     @property
     def edges(self) -> Sequence[Segment]:
@@ -949,10 +954,10 @@ class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
         True
         """
         return self._context.scale_polygon(
-                self, factor_x, factor_x if factor_y is None else factor_y)
+                self, factor_x, factor_x if factor_y is None else factor_y
+        )
 
-    def translate(self, step_x: Scalar, step_y: Scalar
-                  ) -> 'Polygon[Coordinate]':
+    def translate(self, step_x: Scalar, step_y: Scalar) -> 'Polygon[Scalar]':
         """
         Translates the polygon by given step.
 
@@ -1058,11 +1063,14 @@ class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
                 subtract_multipolygon_from_polygon(
                         context.polygon_cls(self.border, []),
                         context.multipolygon_cls([context.polygon_cls(hole, [])
-                                                  for hole in self.holes]))
+                                                  for hole in self.holes])
+                )
                 if len(self.holes) > 1
                 else subtract_polygons(
                         context.polygon_cls(self.border, []),
-                        context.polygon_cls(self.holes[0], [])))
+                        context.polygon_cls(self.holes[0], [])
+                )
+            )
             if border_minus_holes != self:
                 raise ValueError('Holes should not tear polygon apart.')
 
@@ -1070,7 +1078,8 @@ class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
         return self._context.sqrt(
                 self._squared_distance_to_exterior_point(other)
                 if self._locate(other) is Location.EXTERIOR
-                else 0)
+                else 0
+        )
 
     def _distance_to_segment(self, other: Segment) -> Scalar:
         return (self._linear_distance_to_segment(other)
@@ -1080,11 +1089,13 @@ class Polygon(Indexable[Coordinate], Shaped[Coordinate]):
 
     def _linear_distance_to_segment(self, other: Segment) -> Scalar:
         return self._context.segments_squared_distance(
-                self._segment_nearest_edge(other), other)
+                self._segment_nearest_edge(other), other
+        )
 
     def _squared_distance_to_exterior_point(self, other: Point) -> Scalar:
         return self._context.segment_point_squared_distance(
-                self._point_nearest_edge(other), other)
+                self._point_nearest_edge(other), other
+        )
 
     def _unite_with_multipoint(self, other: Multipoint) -> Compound:
         return pack_mix(other - self, self._context.empty, self,
